@@ -12,6 +12,7 @@
 #' @param type A string of the plot type: "LeafAreaDensity", "RootDistribution", "FuelBulkDensity", "PARExtinction", "SWRExtinction" or "WindExtinction". 
 #' @param byCohorts A logical flag to separate profiles for each cohort.
 #' @param bySpecies A logical flag to aggregate results by species.
+#' @param includeHerbs A logical flag to include herbaceous layer in the profile.
 #' @param \dots Additional parameters to vertical profiles
 #' 
 #' @return A ggplot or a shiny application, depending on the function.
@@ -26,16 +27,20 @@
 #' plot(exampleforestMED, SpParamsMED)
 #' 
 #' @name plot.forest
-plot.forest<-function(x, SpParams, type = "LeafAreaDensity", byCohorts = FALSE, bySpecies = FALSE, ...) {
+plot.forest<-function(x, SpParams, type = "LeafAreaDensity", byCohorts = FALSE, bySpecies = FALSE, includeHerbs = FALSE, ...) {
   type = match.arg(type, .forest_plot_choices())
   if(type=="LeafAreaDensity") return(vprofile_leafAreaDensity(x, SpParams = SpParams, draw = TRUE, 
-                                                              byCohorts = byCohorts, bySpecies = bySpecies, ...))
+                                                              byCohorts = byCohorts, bySpecies = bySpecies,
+                                                              includeHerbs = includeHerbs, ...))
   else if(type=="RootDistribution") return(vprofile_rootDistribution(x, SpParams = SpParams,  draw = TRUE, 
                                                                      bySpecies = bySpecies, ...))
   else if(type=="FuelBulkDensity") return(vprofile_fuelBulkDensity(x, SpParams = SpParams,  draw = TRUE, ...))
-  else if(type=="PARExtinction") return(vprofile_PARExtinction(x, SpParams = SpParams,  draw = TRUE, ...))
-  else if(type=="SWRExtinction") return(vprofile_SWRExtinction(x, SpParams = SpParams,  draw = TRUE, ...))
-  else if(type=="WindExtinction") return(vprofile_windExtinction(x, SpParams = SpParams,  draw = TRUE, ...))
+  else if(type=="PARExtinction") return(vprofile_PARExtinction(x, SpParams = SpParams,  draw = TRUE,
+                                                               includeHerbs = includeHerbs, ...))
+  else if(type=="SWRExtinction") return(vprofile_SWRExtinction(x, SpParams = SpParams,  draw = TRUE,
+                                                               includeHerbs = includeHerbs, ...))
+  else if(type=="WindExtinction") return(vprofile_windExtinction(x, SpParams = SpParams,  draw = TRUE,
+                                                                 includeHerbs = includeHerbs, ...))
 }
 
 
@@ -61,6 +66,11 @@ shinyplot.forest<-function(x, SpParams, ...){
           inputId = "byspecies_check",
           label = "Aggregation by species",
           value = FALSE
+        ),
+        checkboxInput(
+          inputId = "includeherbs_check",
+          label = "Include herbaceous layer",
+          value = FALSE
         )
       ),
       mainPanel(
@@ -75,7 +85,8 @@ shinyplot.forest<-function(x, SpParams, ...){
       plot(x, SpParams = SpParams, 
            type = input$plot_main_type, 
            byCohorts = input$bycohort_check,
-           bySpecies = input$byspecies_check)
+           bySpecies = input$byspecies_check,
+           includeHerbs = input$includeherbs_check)
     })
     output$summary <- renderPrint({
       summary(x, SpParams)
