@@ -6,6 +6,8 @@
 using namespace Rcpp;
 
 double soilEvaporationAmount(double DEF,double PETs, double Gsoil);
+double herbaceousTranspiration(double pet, double LherbSWR, double herbLAI, 
+                               List soil, String soilFunctions, bool modifySoil = true);
 NumericVector soilEvaporation(List soil, String soilFunctions, double pet, double LgroundSWR,
                               bool modifySoil = true);
 
