@@ -5,7 +5,7 @@
 #endif
 using namespace Rcpp;
 
-List forest2spwbInput(List x, List soil, DataFrame SpParams, List control, String mode = "MED");
+List forest2spwbInput(List x, List soil, DataFrame SpParams, List control);
 List forest2growthInput(List x, List soil, DataFrame SpParams, List control);
 
 void resetInputs(List x);
